@@ -1,7 +1,7 @@
-# $Id: Gnome2.pm,v 1.14 2005/03/09 14:42:55 jodrell Exp $
+# $Id: Gnome2.pm,v 1.16 2005/06/28 22:57:47 jodrell Exp $
 package Bundle::Gnome2;
 
-$VERSION = '0.08';
+$VERSION = '0.09';
 
 __END__
 
@@ -43,10 +43,18 @@ Gtk2::TrayManager		- Perl bindings for EggTrayManager
 
 Gtk::CV				- a fast gtk+ image viewer modeled after xv
 
+Gtk2::Ex::Datasheet::DBI	- A module that automates the process of setting up a treeview tied to a DBI connection.
+
 Gtk2::Ex::Dialogs		- Useful tools for Gnome2/Gtk2 Perl GUI design.
 
 Gtk2::Ex::FormFactory		- Makes building complex GUI's easy
 
+Gtk2::Ex::Geo			- A Perl Gtk2 widget for spatial data and a glue class for using it
+
+Gtk2::Ex::Graph::GD		- A thin wrapper around the GD::Graph module.
+
+Gtk2::Ex::ICal::Recur		- A widget for scheduling a recurring set of events.
+
 Gtk2::Ex::RecordsFilter		- A high level widget to browse reasonably large amounts of relational data and select a subset of records.
 
 Gtk2::Ex::Simple::List		- A simple interface to Gtk2's complex MVC list widget
@@ -55,6 +63,8 @@ Gtk2::Ex::Simple::Menu		- A simple interface to Gtk2's ItemFactory for creating
 
 Gtk2::Ex::Simple::Tree		- A simple interface to Gtk2's complex MVC tree widget
 
+Gtk2::Ex::TreeMap		- Implementation of TreeMap.
+
 Gtk2::Ex::TreeMaker		- A high level widget to represent a set of relational records in a hierarchical spreadsheet kinda display.
 
 Gtk2::Ex::Utils			- Extra Gtk2 Utilities for working with Gnome2/Gtk2 in Perl.
@@ -63,6 +73,8 @@ Gtk2::Ex::VolumeButton		- widget to control volume and similar values
 
 Gtk2Fu				- GTK2 Forked Ultimate, a powerful layer on top of Gtk2.
 
+Gtk2::GladeXML::Simple		- A clean object-oriented interface to Gtk2::GladeXML
+
 Gnome2::Canvas			- Perl interface to the Gnome Canvas
 
 Gnome2::VFS			- Perl interface to the 2.x series of the GNOME VFS library
